@@ -16,17 +16,16 @@
 
 
 print.summary.fuzzylm = function(x, ...){
-	n = length(x$c)
-	if(x$method %in% c("MOFLR", "PLR")) n = (length(x$c) + 1) / 2
+	n = length(x$center)
 	cat("\nCentral tendency of the fuzzy regression model:\n", ...)
-	cat(x$yvars[1], "=", x$c[1], "+", 
-		paste(x$c[2:n], x$xvars[1:(n-1)], sep=" * ", collapse = " + "), sep = " ", ...)
+	cat(x$center[1], "+", 
+		paste(x$center[2:n], x$xvars[1:(n-1)], sep=" * ", collapse = " + "), sep = " ", ...)
 	cat("\n\nLower boundary of the model support interval:\n", ...)
-	cat(x$yvars[1], "=", x$c[1] - x$l[1], "+", 
-		paste(x$c[2:n] - x$l[2:n], x$xvars[1:(n-1)], sep=" * ", collapse = " + "), sep = " ", ...)
+	cat(x$center[1] - x$left.spread[1], "+", 
+		paste(x$center[2:n] - x$left.spread[2:n], x$xvars[1:(n-1)], sep=" * ", collapse = " + "), sep = " ", ...)
 	cat("\n\nUpper boundary of the model support interval:\n", ...)
-	cat(x$yvars[1], "=", x$c[1] + x$r[1], "+", 
-		paste(x$c[2:n] + x$r[2:n], x$xvars[1:(n-1)], sep=" * ", collapse = " + "), sep = " ", ...)
+	cat(x$center[1] + x$right.spread[1], "+", 
+		paste(x$center[2:n] + x$right.spread[2:n], x$xvars[1:(n-1)], sep=" * ", collapse = " + "), sep = " ", ...)
 	cat("\n\nThe total error of fit:", round(x$TEF, 2), ...)
 	cat("\nThe mean squared distance between response and prediction:", round(x$GOF, 2), ...)
 }
\ No newline at end of file
